==> sphinx_dropdown_toggle-1.0.0-py3-none-any.whl: sphinx_dropdown_toggle/static/dropdown_toggle.js <==
document.addEventListener("DOMContentLoaded", () => {
    const toggleButtonId = "toggle-dropdown-button";
    const rootDropdownState = "dropdowns-opened";

    // Check for dropdowns
    const article = document.querySelector('article.bd-article');
    const dropdowns = article ? article.querySelectorAll('details.dropdown, div.dropdown') : [];
    if (dropdowns.length === 0) {
        return; // Exit if no dropdowns found
    }

    const headerEnd = document.querySelector(".article-header-buttons");
    if (headerEnd) {
        const button = document.createElement("button");
        button.id = toggleButtonId;
        button.className = "btn btn-sm nav-link pst-navbar-icon pst-js-only";
        button.title = "Open all dropdowns";
        button.innerHTML = '<i class="fa-solid fa-angles-down"></i>';

        headerEnd.prepend(button);
    }

    document.getElementById(toggleButtonId)?.addEventListener("click", () => {
        if (document.body.classList.contains(rootDropdownState)) {
            closeDropdowns();
        } else {
            openDropdowns();
        }
    });

    function openDropdowns() {
        document.body.classList.add(rootDropdownState);
        const button = document.getElementById(toggleButtonId);
        if (button) {
            button.innerHTML = '<i class="fa-solid fa-angles-up"></i>';
            button.title = "Close all dropdowns";
        }
        const details = document.querySelectorAll('details.dropdown');
        details.forEach(detail => {
            if (!detail.open) {
                detail.open = true;
            }
        });
        const divs = document.querySelectorAll('div.dropdown');
        divs.forEach(div => {
            div.classList.remove('toggle-hidden');
        });
        const buttons = document.querySelectorAll('button.toggle-button');
        buttons.forEach(button => {
            button.classList.remove('toggle-button-hidden');
        });

        console.log("Dropdowns opened");
    }

    function closeDropdowns() {
        document.body.classList.remove(rootDropdownState);
        const button = document.getElementById(toggleButtonId);
        if (button) {
            button.innerHTML = '<i class="fa-solid fa-angles-down"></i>';
            button.title = "Open all dropdowns";
        }
        const details = document.querySelectorAll('details.dropdown');
        details.forEach(detail => {
            if (detail.open) {
                detail.open = false;
            }
        });
        const divs = document.querySelectorAll('div.dropdown');
        divs.forEach(div => {
            div.classList.add('toggle-hidden');
        });
        const buttons = document.querySelectorAll('button.toggle-button');
        buttons.forEach(button => {
            button.classList.add('toggle-button-hidden');
        });

        console.log("Dropdowns closed");
    }
});

==> sphinx_dropdown_toggle-1.0.1-py3-none-any.whl: sphinx_dropdown_toggle/static/dropdown_toggle.js <==
document.addEventListener("DOMContentLoaded", () => {
    const toggleButtonId = "toggle-dropdown-button";
    const rootDropdownState = "dropdowns-opened";

    // Check for dropdowns
    const article = document.querySelector('article.bd-article');
    const dropdowns = article ? article.querySelectorAll('details.dropdown, div.dropdown, .sd-dropdown') : [];
    if (dropdowns.length === 0) {
        return; // Exit if no dropdowns found
    }

    const headerEnd = document.querySelector(".article-header-buttons");
    if (headerEnd) {
        const button = document.createElement("button");
        button.id = toggleButtonId;
        button.className = "btn btn-sm nav-link pst-navbar-icon pst-js-only";
        button.title = "Open all dropdowns";
        button.innerHTML = '<i class="fa-solid fa-angles-down"></i>';

        headerEnd.prepend(button);
    }

    document.getElementById(toggleButtonId)?.addEventListener("click", () => {
        if (document.body.classList.contains(rootDropdownState)) {
            closeDropdowns();
        } else {
            openDropdowns();
        }
    });

    function openDropdowns() {
        document.body.classList.add(rootDropdownState);
        const button = document.getElementById(toggleButtonId);
        if (button) {
            button.innerHTML = '<i class="fa-solid fa-angles-up"></i>';
            button.title = "Close all dropdowns";
        }
        const details = document.querySelectorAll('details.dropdown, details.sd-dropdown');
        details.forEach(detail => {
            if (!detail.open) {
                detail.open = true;
            }
        });
        const divs = document.querySelectorAll('div.dropdown');
        divs.forEach(div => {
            div.classList.remove('toggle-hidden');
        });
        const buttons = document.querySelectorAll('button.toggle-button');
        buttons.forEach(button => {
            button.classList.remove('toggle-button-hidden');
        });

        console.log("Dropdowns opened");
    }

    function closeDropdowns() {
        document.body.classList.remove(rootDropdownState);
        const button = document.getElementById(toggleButtonId);
        if (button) {
            button.innerHTML = '<i class="fa-solid fa-angles-down"></i>';
            button.title = "Open all dropdowns";
        }
        const details = document.querySelectorAll('details.dropdown, details.sd-dropdown');
        details.forEach(detail => {
            if (detail.open) {
                detail.open = false;
            }
        });
        const divs = document.querySelectorAll('div.dropdown');
        divs.forEach(div => {
            div.classList.add('toggle-hidden');
        });
        const buttons = document.querySelectorAll('button.toggle-button');
        buttons.forEach(button => {
            button.classList.add('toggle-button-hidden');
        });

        console.log("Dropdowns closed");
    }
});
